//
//  CWMOdel.m
//  ResaISkane
//
//  Copyright 2009-2010 Fredrik Olsson. All rights reserved.
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License. 
//  You may obtain a copy of the License at 
// 
//  http://www.apache.org/licenses/LICENSE-2.0 
//  
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS, 
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
//

#import "CWModel.h"
#import "NSDate+CWExtentions.h"

@implementation CWModel

@synthesize knownPoints = _knownPoints;
@synthesize bookmarkedJourneys = _bookmarkedJourneys;
@synthesize date = _date;
@synthesize direction = _direction;
@synthesize from = _from;
@synthesize to = _to;
@synthesize currentJourneyList = _currentJourneyList;
@synthesize translateTexts = _translateTexts;

static CWModel* sharedModel = nil;

+(NSString*)sharedModelFileName;
{
	NSString* path = [NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES) objectAtIndex:0];
  return [path stringByAppendingPathComponent:@"model.dat"];
}

+(CWModel*)sharedModel;
{
	if (sharedModel == nil) {
    sharedModel = [[NSKeyedUnarchiver unarchiveObjectWithFile:[self sharedModelFileName]] retain];
    if (sharedModel == nil) {
    	sharedModel = [[CWModel alloc] init];
      [sharedModel.knownPoints addObjectsFromArray:[CWPoint defaultKnownPoints]];
    }
  }
  return sharedModel;
}

-(BOOL)persistToStorage;
{
	return [NSKeyedArchiver archiveRootObject:self toFile:[CWModel sharedModelFileName]];
}

-(id)init;
{
	self = [super init];
  if (self) {
    self.knownPoints = [NSMutableArray new];
    self.bookmarkedJourneys = [NSMutableArray new];
    self.date = [NSDate relativeDateWithTimeIntervalSinceNow:0];
    self.direction = CWJourneyDirectionDeparture;
  }
  return self;
}

-(void)dealloc;
{
  self.knownPoints = nil;
  self.bookmarkedJourneys = nil;
  self.date = nil;
  self.from = nil;
  self.to = nil;
  [super dealloc];
}

-(void)addJourneys:(NSArray*)journeys;
{
  if (_currentJourneyList == nil) {
		_currentJourneyList = [[NSMutableArray alloc] init];
  }
  if ([journeys count]) {
    if ([_currentJourneyList count] && [[[journeys objectAtIndex:0] departure] timeIntervalSinceReferenceDate] < [[[_currentJourneyList objectAtIndex:0] departure] timeIntervalSinceReferenceDate]) {
      for (id journey in [journeys reverseObjectEnumerator]) {
        [_currentJourneyList insertObject:journey atIndex:0];
      }
    } else {
      [_currentJourneyList addObjectsFromArray:journeys];
    }
  }
}

-(void)clearJourneys;
{
	[_currentJourneyList release];
  _currentJourneyList = nil;
}

-(id)initWithCoder:(NSCoder *)aDecoder;
{
  self = [super init];
  if (self) {
    self.knownPoints= [aDecoder decodeObjectForKey:@"knownPoints"];
    self.bookmarkedJourneys = [aDecoder decodeObjectForKey:@"bookmarkedJourneys"];
    self.date = [aDecoder decodeObjectForKey:@"date"];
    self.direction = [aDecoder decodeIntegerForKey:@"direction"];
    self.from = [aDecoder decodeObjectForKey:@"from"];
    self.to = [aDecoder decodeObjectForKey:@"to"];
    self.currentJourneyList = [aDecoder decodeObjectForKey:@"currentJourneyList"];
    self.translateTexts = [aDecoder decodeBoolForKey:@"translateTexts"];
  }
  return self;
}

-(void)encodeWithCoder:(NSCoder *)aCoder;
{
  [aCoder encodeObject:self.knownPoints forKey:@"knownPoints"];
  [aCoder encodeObject:self.bookmarkedJourneys forKey:@"bookmarkedJourneys"];
  [aCoder encodeObject:self.date forKey:@"date"];
  [aCoder encodeInteger:self.direction forKey:@"direction"];
  [aCoder encodeObject:self.from forKey:@"from"];
  [aCoder encodeObject:self.to forKey:@"to"];
	[aCoder encodeObject:self.currentJourneyList forKey:@"currentJourneyList"];
  [aCoder encodeBool:self.translateTexts forKey:@"translateTexts"];
}

@end
