//
//  CWXMLParser.h
//  XmlTranslater
//
//  Copyright 2009-2010 Jayway. All rights reserved.
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License. 
//  You may obtain a copy of the License at 
// 
//  http://www.apache.org/licenses/LICENSE-2.0 
//  
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS, 
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
//

#import <Foundation/Foundation.h>


@protocol CWXMLTranslaterDelegate;

/*!
 * @abstract A utility class for traslating a XML document into an object graph.
 *
 * @discussion The translation to apply is defined in a property list. Objects to create must be KVC-complient for the 
 *             properties to translate. The root objects will be sent to the delegate, and all other objects int he graph
 *             will be set as properties on their parent.
 *             Translation is a blocking call, and should be called from a background thread.
 *             PLIST FORMAT IS NOT DOCUMENTED AND CAN/WILL CHANGE.
 */
@interface CWXMLTranslater : NSObject {
@private
  id<CWXMLTranslaterDelegate> _delegate;
	NSDictionary* translationPlist;
  id<CWXMLTranslaterDelegate> currentDelegate;
	NSMutableArray* stateStack;
  NSMutableString* currentText;
}

@property(nonatomic, assign) id<CWXMLTranslaterDelegate> delegate; //! Tranlation delegte.

/*!
 * @abstract Init translater with delegate to send created root objects to.
 */
-(id)initWithTranslationPropertyList:(NSDictionary*)translationPlist delegate:(id<CWXMLTranslaterDelegate>)delegate;

/*!
 * @abstract Translate the XML document refenced by an URL.
 */
-(BOOL)translateContentsOfURL:(NSURL*)url;

/*!
 * @abstract Translet the XML document referenced by an URL using the no default delegate and an optional out error argument.
 */
-(BOOL)translateContentsOfURL:(NSURL*)url delegate:(id<CWXMLTranslaterDelegate>)delegate error:(NSError**)error;


@end


/*!
 * @abstract Delegate for handling he result of a XML transltion.
 */
@protocol CWXMLTranslaterDelegate <NSObject>

@required
/*!
 * @abstract Translater did translate a root obejct for a specified key.
 */
-(void)xmlTranslater:(CWXMLTranslater*)translater didTranslateObject:(id)anObject forKey:(NSString*)key;

@optional
/*!
 * @abstract Translater will translate a specified value for a key.
 *
 * @discussion Return a translation to override the default translation, otherwise return nil.
 */
-(id)xmlTranslater:(CWXMLTranslater*)translater willTranslateValueOfClass:(Class)aClass withString:(NSString*)aString forKey:(NSString*)key;

/*!
 * @abstract Translater will translate an object for a specified key.
 *
 * @discussion Return an autoreleased and initialized object if you need a custom object initialization, otherwise return nil.
 */
-(id)xmlTranslater:(CWXMLTranslater*)translater willTranslateObjectOfClass:(Class)aClass forKey:(NSString*)key;

@end

